@@ -423,7 +423,11 @@ class JsonList(list):
         columns = self.list_type().get_columns()
         return DataFrame([i.get_values() for i in self], columns=columns)
 
-
-
-
-
+    def from_dataframe(self, df):
+        self.clear()
+        columns = df.columns
+        for i, row in df.iterrows():
+            ni = self.list_type()
+            for c in columns:
+                ni[c] = row[c]
+            self.append(ni)
